import pytest
import stk

from ..case_data import CaseData


def _get_case_data_1() -> CaseData:
    topology_graph = stk.polymer.Linear(
        building_blocks=[
            stk.BuildingBlock("BrCCBr", stk.BromoFactory()),
        ],
        repeating_unit="A",
        num_repeating_units=2,
    )
    return CaseData.new(
        fitness_normalizer=stk.Sum(
            filter=lambda fitness_values, record: fitness_values[record]
            is not None,
        ),
        fitness_values={
            stk.MoleculeRecord(
                topology_graph=topology_graph,
            ): ((1, -5, 5), 1),
            stk.MoleculeRecord(
                topology_graph=topology_graph,
            ): ((3, -10, 2), -5),
            stk.MoleculeRecord(
                topology_graph=topology_graph,
            ): ((2, 20, 1), 23),
            stk.MoleculeRecord(topology_graph): (None, None),
        },
    )


@pytest.fixture(
    scope="session",
    params=(_get_case_data_1,),
)
def sum(request: pytest.FixtureRequest) -> CaseData:
    return request.param()



def test_repr(case_data):
    """
    Test :meth:`.BuildingBlock.__repr__`.

    Parameters
    ----------
    case_data : :class:`.CaseData`
        A test case. Holds the building block to test and the correct
        functional groups.

    Returns
    -------
    None : :class:`NoneType`

    """

    _test_repr(
        building_block=case_data.building_block,
        known_repr=case_data.known_repr,
    )


def _test_repr(building_block, known_repr):
    """
    Test :meth:`.BuildingBlock.get_functional_groups`.

    Parameters
    ----------
    building_block : :class:`.BuildingBlock`
        The building block to test.

    functional_groups : :class:`tuple` of :class:`.FunctionalGroup`
        The correct functional groups.

    Returns
    -------
    None : :class:`NoneType`

    """
    print(building_block.__repr__(), known_repr)
    assert building_block.__repr__() == known_repr
